@@ -47,6 +47,7 @@ class List(Storm):
 
     name = Unicode(primary=True)
     display_name = Unicode()
+    description = Unicode()
 
     def __init__(self, name):
         self.name = unicode(name)
@@ -74,6 +75,8 @@ class Email(Storm):
     message_id_hash = Unicode()
     thread_id = Unicode()
     archived_date = DateTime(default_factory=datetime.datetime.now)
+    thread_depth = Int(default=0)
+    thread_order = Int(default=0)
     # path is required by IMessage, but it makes no sense here
     path = None
     # References
@@ -110,11 +113,10 @@ class EmailFull(Storm):
     email = Reference((list_name, message_id),
                      ("Email.list_name", "Email.message_id"))
 
-    def __init__(self, list_name, message_id, full=None):
+    def __init__(self, list_name, message_id, full):
         self.list_name = unicode(list_name)
         self.message_id = unicode(message_id)
-        if full is not None:
-            self.full = full
+        self.full = full
 
 
 class Attachment(Storm):
@@ -152,6 +154,11 @@ class Thread(Storm):
                 (Email.list_name, Email.thread_id),
                 order_by=Email.date
              )
+    emails_by_reply = ReferenceSet(
+                (list_name, thread_id),
+                (Email.list_name, Email.thread_id),
+                order_by=Email.thread_order
+             )
     _starting_email = None
 
     def __init__(self, list_name, thread_id, date_active=None):
@@ -202,6 +209,10 @@ class Thread(Storm):
     def email_ids(self):
         return list(self.emails.find().order_by().values(Email.message_id))
 
+    @property
+    def email_id_hashes(self):
+        return list(self.emails.find().order_by().values(Email.message_id_hash))
+
     def __len__(self):
         return self.emails.count()
 
@@ -209,5 +220,9 @@ class Thread(Storm):
         """Auto-set the active date from the last email in thread"""
         if self.date_active is not None:
             return
-        self.date_active = list(self.emails.order_by(Desc(Email.date)
-                                ).config(limit=1).values(Email.date))[0]
+        email_dates = list(self.emails.order_by(Desc(Email.date)
+                                ).config(limit=1).values(Email.date))
+        if email_dates:
+            self.date_active = email_dates[0]
+        else:
+            self.date_active = datetime.datetime.now()
