@@ -28,6 +28,7 @@ from kittystore.utils import parseaddr, parsedate
 from kittystore.utils import header_to_unicode
 from kittystore.scrub import Scrubber
 from kittystore.utils import get_ref_and_thread_id
+from kittystore.analysis import compute_thread_order_and_depth
 
 from .model import List, Email, Attachment, Thread, EmailFull
 
@@ -84,12 +85,12 @@ class StormStore(object):
         """
         list_name = unicode(mlist.fqdn_listname)
         # Create the list if it does not exist
-        list_is_in_db = self.db.find(List,
-                List.name == list_name).count()
-        if not list_is_in_db:
+        l = self.db.find(List, List.name == list_name).one()
+        if l is None:
             l = List(list_name)
-            l.display_name = mlist.display_name
             self.db.add(l)
+        l.display_name = mlist.display_name
+        l.description = mlist.description
         if not message.has_key("Message-Id"):
             raise ValueError("No 'Message-Id' header in email", message)
         msg_id = unicode(unquote(message['Message-Id']))
@@ -153,9 +154,10 @@ class StormStore(object):
 
         self.db.add(email)
         self.db.add(email_full)
-        self.flush()
+        compute_thread_order_and_depth(thread)
         for attachment in attachments:
             self.add_attachment(list_name, msg_id, *attachment)
+        self.flush()
         return email.message_id_hash
 
     def delete_message(self, message_id):
@@ -180,14 +182,14 @@ class StormStore(object):
         msg = self.get_message_by_id_from_list(list_name, message_id)
         if msg is None:
             raise MessageNotFound(list_name, message_id)
-        self.db.delete(msg)
+        self.db.remove(msg)
         # Remove the thread if necessary
         thread = self.db.find(Thread, And(
                         Thread.list_name == msg.list_name,
                         Thread.thread_id == msg.thread_id,
                         )).one()
         if len(thread.emails) == 0:
-            self.db.delete(thread)
+            self.db.remove(thread)
         self.flush()
 
     def get_list_size(self, list_name):
@@ -333,6 +335,13 @@ class StormStore(object):
         """
         return list(self.db.find(List.name).order_by(List.name))
 
+    def get_lists(self):
+        """Return the archived lists.
+
+        :returns: A list containing the archived mailing-lists.
+        """
+        return list(self.db.find(List).order_by(List.name))
+
     def get_messages(self, list_name, start, end):
         """ Return all emails between two given dates.
 
